/*
 * CaloQtotVsRigHistoAction.h
 *
 *  Created on: 09/mar/2010
 *      Author: S. Ricciarini
 */

/*! @file CaloQtotVsRigHistoAction.h The CaloQtotVsRigHistoAction class declaration file. */

#ifndef CALOQTOTVSRIGHISTOACTION_H_
#define CALOQTOTVSRIGHISTOACTION_H_

#include "../Histo2DAction/Histo2DAction.h"

/*! @brief An action that fills a Calo Qtot Vs. Trk Rig (modulus) histogram. */
class CaloQtotVsRigHistoAction: public Histo2DAction<Int_t> {

public:

  /*! @brief Constructor.
   *
   * @param actionName The action's name.
   * @param outFileBase The file base name for the ROOT histogram output (".root" will be appended).
   *                    If "", no ROOT output will be produced.
   * @param mode The mode of ROOT file creation (see documentation of TFile constructor
   *             in ROOT's reference guide).
   * @param outRoot If true, an output ROOT file named outFileBase + ".root" will be produced.
   * @param outText If true, an output text file named outFileBase + ".txt" will be produced. It will overwrite an
   *                eventually existing file with the same name.
   * @param title The ROOT histogram title.
   */
  CaloQtotVsRigHistoAction(const char *actionName, TString outFileBase = "", TString mode = "UPDATE", bool outRoot =
      true, bool outText = true, TString title = "CAL Qtot Vs. TRK Rig");

  /*! @brief Destructor */
  ~CaloQtotVsRigHistoAction() {
  }

  /*! @brief Fills histogram with the selected event.
   *
   * @param event The selected event.
   */
  void OnGood(PamLevel2 *event);


};
#endif /* CALOQTOTVSRIGHISTOACTION_H_ */
